# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# -*- coding: utf-8 -*-

__author__ = """Marquez Project"""
__version__ = "0.14.0"

from marquez_client.client import MarquezClient              # noqa: F401
from marquez_client.client_wo import MarquezWriteOnlyClient  # noqa: F401
from marquez_client.clients import Clients                   # noqa: F401
